@@ -1,18 +1,11 @@
 /* App.m
  * Application class of Cenon
  *
- * Copyright (C) 1995-2012 by vhf interservice GmbH
+ * Copyright (C) 1995-2007 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1995-08-10
- * modified: 2011-03-06 (-applicationDidFinishLunching: auto check for updates)
- *           2010-07-04 (svg stuff added)
- *           2010-06-30 (-changeSafeType: TIFF added)
- *           2010-04-10 (displayInfo: get version from plist and date from __DATE__)
- *           2010-01-12 (take snapshot of open documents and their positions)
- *           2009-06-24
- *           2009-03-27 (-sendEvent: ',' -> '.' on Apple)
- *           2009-02-25 (-listFromFile: check extensions for any case)
+ * modified: 2007-07-19
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -50,7 +43,6 @@
 #include "DocView.h"
 #include "DocWindow.h"
 #include "PreferencesMacros.h"
-#include "UpdateController.h"
 
 #include "DINImportSub.h"
 #include "DXFImportSub.h"
@@ -58,7 +50,6 @@
 #include "HPGLImportSub.h"
 #include "PSImportSub.h"
 #include "Type1ImportSub.h"
-//#include "SVGImportSub.h"
 
 @implementation App
 
@@ -133,47 +124,16 @@
     fixedDocument = docu;
 }
 
-- (void)setActiveDocWindow:(DocWindow*)win
-{
-    activeWindowNum = [win windowNumber];
-}
-
 - (Document*)currentDocument
 {
     if (fixedDocument)
         return fixedDocument;
-    /* this is unreliable, because a panel may become the main window! */
-    if ( [[self mainWindow] isMemberOfClass:[DocWindow class]] )
+    else if ( [[self mainWindow] isMemberOfClass:[DocWindow class]] )
     {	id	docu = [(DocWindow*)[self mainWindow] document];
 
         if ([docu isMemberOfClass:[Document class]])
             return docu;
     }
-    {   NSArray *wins = [self windows];
-        int     i, cnt = [wins count];
-
-        for (i=0; i<cnt; i++)
-            if ( [[wins objectAtIndex:i] windowNumber] == activeWindowNum )
-                return [[wins objectAtIndex:i] document];
-    }
-    /* does this really return the window last worked at? Probably we should remember the active document */
-    /*for ( i=[[self windows] count]-1; i >= 0; i-- )
-    {	DocWindow  *win = [[self windows] objectAtIndex:i];
-
-        if ( [win isMemberOfClass:[DocWindow class]] )
-            return [win document];
-    }*/
-    /*{   int wins[10];
-
-        //NSCountWindowsForContext([self context], &nWin);
-        NSWindowListForContext([self context], 10, wins);   // how to obtain the context? What context is that?
-        for ( i=0; i < 10; i++ )
-        {   DocWindow  *win = wins[i];
-
-            if ( [win isMemberOfClass:[DocWindow class]] )
-                return [win document];
-        }
-    }*/
     return nil;
 }
 - (Document*)openedDocument
@@ -212,13 +172,13 @@
  * modified: 2005-09-05 (load module only once)
  */
 - (void)loadModules
-{   NSBundle        *mainBundle = [NSBundle mainBundle], *bundle;
-    Class           bundleClass;
-    NSString        *path;
-    int             i, j;
-    NSFileManager   *fileManager = [NSFileManager defaultManager];
-    BOOL            camModuleLoaded = NO;
-    NSMutableArray  *loadedFiles = [NSMutableArray array];
+{   NSBundle		*mainBundle = [NSBundle mainBundle], *bundle;
+    Class		bundleClass;
+    NSString		*path;
+    int			i, j;
+    NSFileManager	*fileManager = [NSFileManager defaultManager];
+    BOOL		camModuleLoaded = NO;
+    NSMutableArray	*loadedFiles = [NSMutableArray array];
 
     /* load modules from application bundle
      * FIXME: The CAM module should be integrated below (case 0)
@@ -229,9 +189,9 @@
     path = [mainBundle pathForResource:@"CAM" ofType:@"bundle"];
     if ( (bundle = [NSBundle bundleWithPath:path]) )
     {
-        bundleClass = [bundle principalClass];  // controller
-        [modules addObject:bundle];             // our loaded modules
-        [bundleClass instance];                 // create instance
+        bundleClass = [bundle principalClass];	// controller
+        [modules addObject:bundle];		// our loaded modules
+        [bundleClass instance];			// create instance
         camModuleLoaded = YES;
     }
 
@@ -258,12 +218,12 @@
             if (camModuleLoaded && [file hasPrefix:@"Cut."])	// either CAM or Cut, not both
                 continue;
             if ( [file hasSuffix:@".bundle"] &&
-                 ![loadedFiles containsObject:file] &&  // already loaded ?
+                 ![loadedFiles containsObject:file] &&	// already loaded ?
                  (bundle = [NSBundle bundleWithPath:[path stringByAppendingPathComponent:file]]) )
             {
-                bundleClass = [bundle principalClass];  // controller
-                [modules addObject:bundle];             // our loaded modules
-                [bundleClass instance];                 // create instance
+                bundleClass = [bundle principalClass];	// controller
+                [modules addObject:bundle];		// our loaded modules
+                [bundleClass instance];			// create instance
                 [loadedFiles addObject:file];
             }
         }
@@ -275,7 +235,7 @@
 }
 
 /* created:  1993-01-??
- * modified: 2011-03-06
+ * modified: 2005-11-18
  */
 - (void)applicationDidFinishLaunching:(NSNotification *)notification
 {   NSApplication	*theApplication = [notification object];
@@ -326,25 +286,6 @@
 #endif
 
     [NSThread sleepUntilDate:[NSDate dateWithTimeIntervalSinceNow:500.0/1000000.0]];
-
-    /* Load Document Snapshot */
-    [self restoreSnapshot:self];
-
-#ifdef __APPLE__
-    /* automatically check for updates */
-    [[UpdateController sharedInstance] checkForUpdates:self];
-    /*[[NSRunLoop currentRunLoop] performSelector:@selector(checkForUpdates:)
-     target:[UpdateController sharedInstance]
-     argument:self order:10 modes:NSDefaultRunLoopMode];*/
-#endif
-
-#ifdef GNUSTEP_BASE_VERSION
-    /* menu in window */
-    if (NSInterfaceStyleForKey(@"NSMenuInterfaceStyle", nil) == NSWindows95InterfaceStyle)
-    {
-        [self new:self];
-    }
-#endif
 }
 
 
@@ -361,18 +302,14 @@
     document = [Document new];
 }
 
-/* modified: 2010-09-10 (defaultManager renamed to fileManager)
- *           2009-02-25 (fileNameLC)
- */
 - (id)listFromFile:(NSString*)fileName
-{   NSArray         *list = nil;
-    NSString        *path, *name;
-    NSFileManager   *fileManager = [NSFileManager defaultManager];
-    NSString        *fileNameLC = [fileName lowercaseString];
+{   NSArray		*list = nil;
+    NSString		*path, *name;
+    NSFileManager	*defaultManager = [NSFileManager defaultManager];
 
     //if ( [fileName rangeOfString:@".dxf" options:NSCaseInsensitiveSearch].length )
     //if ( [fileName compare:@".dxf" options:NSAnchoredSearch|NSBackwardsSearch|NSCaseInsensitiveSearch] )
-    if ( [fileNameLC hasSuffix:@".dxf"] )
+    if ( [fileName hasSuffix:@".dxf"] || [fileName hasSuffix:@".DXF"] )
     {	id	dxfImport = [[DXFImportSub allocWithZone:[self zone]] init];
         NSData	*data = [NSData dataWithContentsOfFile:fileName];	// get data object
 
@@ -380,21 +317,18 @@
         list = [[dxfImport importDXF:data] retain];	// get list of graphic-objects from import
         [dxfImport release];
     }
-    else if ( [fileNameLC hasSuffix:@".hpgl"] || [fileNameLC hasSuffix:@".hgl"] ||
-              [fileNameLC hasSuffix:@".plt"] )
-    {	id      hpglImport;
+    else if ( [fileName hasSuffix:@".hpgl"] || [fileName hasSuffix:@".hgl"] || [fileName hasSuffix:@".plt"] )
+    {	id	hpglImport;
         NSData	*data;
 
         /* load parameter file
          * 1st try it in the users home library then try it in /LocalLibrary
          */
-        name = Prefs_HPGLParmsFileName;
-        if ( ![name length] ) name = @"hpgl_8Pen";  // workaround GNUstep issue with registering defaults
-        name = [name stringByAppendingPathExtension:DEV_EXT];
+        name = [Prefs_HPGLParmsFileName stringByAppendingPathExtension:DEV_EXT];
         path = vhfPathWithPathComponents(userLibrary(), HPGLPATH, name, nil);
-        if ( ![fileManager fileExistsAtPath:path] )
+        if ( ![defaultManager fileExistsAtPath:path] )
         {   path = vhfPathWithPathComponents(localLibrary(), HPGLPATH, name, nil);
-            if ( ![fileManager fileExistsAtPath:path] )
+            if ( ![defaultManager fileExistsAtPath:path] )
             {	NSRunAlertPanel(@"", CANTLOADFILE_STRING, OK_STRING, nil, nil, path);
                 return nil;
             }
@@ -409,20 +343,18 @@
         list = [[hpglImport importHPGL:data] retain];		// get list of graphic-objects from import
         [hpglImport release];
     }
-    else if ( [fileNameLC hasSuffix:@".ger"] || [fileNameLC hasSuffix:@".gerber"] )
-    {   id      gerberImport;
-        NSData  *data;
+    else if ( [fileName hasSuffix:@".ger"] || [fileName hasSuffix:@".gerber"] )
+    {   id	gerberImport;
+        NSData	*data;
 
         /* load parameter file
          * 1st try it in the users home library then try it in /LocalLibrary
          */
-        name = Prefs_GerberParmsFileName;
-        if ( ![name length] ) name = @"gerber"; // workaround GNUstep issue with registering defaults
-        name = [name stringByAppendingPathExtension:DEV_EXT];
+        name = [Prefs_GerberParmsFileName stringByAppendingPathExtension:DEV_EXT];
         path = vhfPathWithPathComponents(userLibrary(), GERBERPATH, name, nil);
-        if ( ![fileManager fileExistsAtPath:path] )
+        if ( ![defaultManager fileExistsAtPath:path] )
         {   path = vhfPathWithPathComponents(localLibrary(), GERBERPATH, name, nil);
-            if ( ![fileManager fileExistsAtPath:path] )
+            if ( ![defaultManager fileExistsAtPath:path] )
             {	NSRunAlertPanel(@"", CANTLOADFILE_STRING, OK_STRING, nil, nil, path);
                 return nil;
             }
@@ -466,10 +398,10 @@
         list = [[gerberImport importGerber:data] retain];	// get list of graphic-objects from import
         [gerberImport release];
     }
-    else if ( [fileNameLC hasSuffix:@".drl"] || [fileNameLC hasSuffix:@".din"] )
-    {   id          dinImport;
-        NSData      *data;
-        NSString    *devFileName;
+    else if ( [fileName hasSuffix:@".drl"] || [fileName hasSuffix:@".din"] )
+    {   id		dinImport;
+        NSData		*data;
+        NSString	*devFileName;
 
         /* look for parameter file
          * 1st try it in the users home library then try it in /LocalLibrary
@@ -478,9 +410,9 @@
         {
             name = [devFileName stringByAppendingPathExtension:DEV_EXT];
             path = vhfPathWithPathComponents(userLibrary(), DINPATH, name, nil);
-            if ( ![fileManager fileExistsAtPath:path] )
+            if ( ![defaultManager fileExistsAtPath:path] )
             {   path = vhfPathWithPathComponents(localLibrary(), DINPATH, name, nil);
-                if ( ![fileManager fileExistsAtPath:path] )
+                if ( ![defaultManager fileExistsAtPath:path] )
                 {   NSRunAlertPanel(@"", CANTLOADFILE_STRING, OK_STRING, nil, nil, path);
                     return nil;
                 }
@@ -500,23 +432,16 @@
         list = [[DINImportSub layerListFromGraphicList:list] retain];
         [dinImport release];
     }
-    /*else if ( [fileNameLC hasSuffix:@".svg"] )
-    {	SVGImport   *svgImport = [[SVGImportSub allocWithZone:[self zone]] init];
-        NSData      *data = [NSData dataWithContentsOfFile:fileName];
-
-        list = [[svgImport importSVG:data] retain]; // get list of graphic-objects from import
-        [svgImport release];
-    }*/
-    else if ( [fileNameLC hasSuffix:@".font"] || [fileNameLC hasSuffix:@".pfa"] || [fileNameLC hasSuffix:@".pfb"] )
-    {   id          fontObject, type1Import;
+    else if ( [fileName hasSuffix:@".font"] || [fileName hasSuffix:@".pfa"] || [fileName hasSuffix:@".pfb"] )
+    {   id		fontObject, type1Import;
         NSData		*data;
         NSString	*name;
 
-        if ( [fileNameLC hasSuffix:@".pfa"] || [fileNameLC hasSuffix:@".pfb"] )	// pfa file
+	if ( [fileName hasSuffix:@".pfa"] || [fileName hasSuffix:@".pfb"] )	// pfa file
             name = [NSString stringWithFormat:@"%@", fileName];
-        else
+	else
             name = [fileName stringByAppendingPathComponent:
-        [[fileName lastPathComponent] stringByDeletingPathExtension]];
+                [[fileName lastPathComponent] stringByDeletingPathExtension]];
         type1Import = [[Type1ImportSub allocWithZone:[self zone]] init];	// get new import-object
         data = [NSData dataWithContentsOfFile:name];				// get file-data
 
@@ -526,12 +451,12 @@
     }
 
     /* PostScript, AI */
-    else if ( [fileNameLC hasSuffix:@".eps"] || [fileNameLC hasSuffix:@".ps"] ||
-              [fileNameLC hasSuffix:@".ai"] )
+    else if ( [fileName hasSuffix:@".eps"] || [fileName hasSuffix:@".ps"] ||
+              [fileName hasSuffix:@".ai"] )
         list = [[self listFromPSFile:fileName] retain];
 
     /* PDF */
-    else if ( [fileNameLC hasSuffix:@".pdf"] || [fileNameLC hasSuffix:@".PDF"])
+    else if ( [fileName hasSuffix:@".pdf"] || [fileName hasSuffix:@".PDF"])
     {   PSImportSub	*psImport = [[PSImportSub allocWithZone:[self zone]] init];
 
         [psImport preferArcs:Prefs_PSPreferArcs];
@@ -590,9 +515,9 @@
 }
 
 - (BOOL)openFile:(NSString *)fileName
-{   id              list = 0;
-    NSString        *path;
-    NSFileManager   *fileManager = [NSFileManager defaultManager];
+{   id			list = 0;
+    NSString		*path;
+    NSFileManager	*fileManager = [NSFileManager defaultManager];
 
     if (!appIsRunning)	// give application a chance to load modules first
     {
@@ -630,7 +555,7 @@
             [self setCurrentDocument:nil];
             [document setName:UNTITLED_STRING andDirectory:[self currentDirectory]];
             [document setDirty:YES];
-            [document setFontObject:list]; // add font data, font list
+            [document setFontObject:list]; // font daten + font list hinzufgen
         }
         /* imports with complete layerList or a single list of objects */
         else
@@ -644,7 +569,7 @@
 }
 
 /* Import files
- * modified: 2010-02-24 (allow extension ".tif")
+ * modified: 20005-09-25
  */
 typedef enum
 {   IMPORTTO_SELECTEDLAYER  = 0,
@@ -652,26 +577,26 @@ typedef enum
     IMPORTTO_EXISTINGLAYERS = 2
 } ImportToLayerSelection;
 - (void)import:sender
-{   NSArray     *fileTypes = [NSArray arrayWithObjects:@"hpgl", @"hgl", @"plt", @"ai",
+{   NSArray		*fileTypes = [NSArray arrayWithObjects:@"hpgl", @"hgl", @"plt", @"ai",
                                               @"dxf", @"eps", @"ps", @"pdf", @"gerber", @"ger",
-                                              @"cenon", @"tiff", @"tif", @"jpg", @"jpeg", @"gif", @"png",
-                                              @"font", @"pfa", @"din", @"drl", @"svg", nil];
-    NSString    *fileName;
-    id          openPanel = [NSOpenPanel openPanel];
-    static      NSString	*openDir = @"";
+                                              @"cenon", @"tiff", @"jpg", @"gif",
+                                              @"font", @"pfa", @"din", @"drl", nil];
+    NSString		*fileName;
+    id			openPanel = [NSOpenPanel openPanel];
+    static NSString	*openDir = @"";
 
     [openPanel setAccessoryView:[importAccessory retain]];
     [openPanel setAllowsMultipleSelection:NO];
 
     if ( [openPanel runModalForDirectory:openDir file:@"" types:fileTypes] )
     {   ImportToLayerSelection	importTo = [iaPopup indexOfSelectedItem];
-        id      list;
-        DocView *view = [[self currentDocument] documentView];
+        id			list;
+        DocView			*view = [[self currentDocument] documentView];
 
         [openDir release];
         openDir = [[[openPanel filename] stringByDeletingLastPathComponent] retain];
 
-        fileName = [openPanel filename];
+	fileName = [openPanel filename];
         list = [self listFromFile:fileName];
 
         switch (importTo)
@@ -739,14 +664,14 @@ typedef enum
  * and loads the specified file into it.
  */
 - (void)openDocument:sender
-{   NSArray     *fileTypes = [NSArray arrayWithObjects:@"hpgl", @"hgl", @"plt", @"ai",
-                                  @"dxf", @"eps", @"ps", @"pdf", @"gerber", @"ger",
-                                  @"cenon", @"tiff", @"tif", @"jpg", @"jpeg", @"gif", @"png",
-                                  @"font", @"pfa", @"din", @"drl", @"svg", nil];
-    NSArray         *fileNames;
-    id              openPanel = [NSOpenPanel openPanel];
-    int             i, cnt;
-    static NSString *openDir = @"";
+{   NSArray		*fileTypes = [NSArray arrayWithObjects:@"hpgl", @"hgl", @"plt", @"ai",
+                                              @"dxf", @"eps", @"ps", @"pdf", @"gerber", @"ger",
+                                              @"cenon", @"tiff", @"jpg", @"gif",
+                                              @"font", @"pfa", @"din", @"drl", nil];
+    NSArray		*fileNames;
+    id			openPanel = [NSOpenPanel openPanel];
+    int			i, cnt;
+    static NSString	*openDir = @"";
 
     [openPanel setAllowsMultipleSelection:YES];
     if ( [openPanel runModalForDirectory:openDir file:@"" types:fileTypes] )
@@ -754,10 +679,10 @@ typedef enum
         [openDir release];
         openDir = [[[openPanel filename] stringByDeletingLastPathComponent] retain];
 
-        fileNames = [openPanel filenames];
+	fileNames = [openPanel filenames];
         cnt = [fileNames count];
-        for ( i=0; i<cnt; i++ )
-            haveOpenedDocument = [self openFile:[fileNames objectAtIndex:i]] || haveOpenedDocument;
+	for ( i=0; i<cnt; i++ )
+	    haveOpenedDocument = [self openFile:[fileNames objectAtIndex:i]] || haveOpenedDocument;
     }
 }
 
@@ -786,9 +711,8 @@ typedef enum
         case 2: [savePanel setRequiredFileType:GERBER_EXT]; break;
         case 3: [savePanel setRequiredFileType:DXF_EXT]; break;
         case 4: [savePanel setRequiredFileType:HPGL_EXT]; break;
-        case 5: [savePanel setRequiredFileType:TIFF_EXT]; break;
-        case 6: [savePanel setRequiredFileType:FONT_EXT]; break;
-        case 7: [savePanel setRequiredFileType:DIN_EXT]; break;
+        case 5: [savePanel setRequiredFileType:FONT_EXT]; break;
+        case 6: [savePanel setRequiredFileType:DIN_EXT]; break;
         default: NSLog(@"App, changeFileType: Unknown file type");
     }
 }
@@ -889,105 +813,6 @@ typedef enum
     return YES;
 }
 
-/* Snapshots
- * created:  2010-01-12
- * modified: 2010-04-23
- */
-- (void)takeSnapshot:sender
-{   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
-    NSMutableArray  *snapArray = [NSMutableArray array];
-    int             count;
-
-    for ( count=[[self windows] count]-1; count>=0; count-- )
-    {	Document    *doc = [self documentInWindow:[[self windows] objectAtIndex:count]];
-
-        if (doc)
-        {   DocWindow   *window = [doc window];
-            NSString    *rString = propertyListFromNSRect([window frame]);
-            NSString    *sString = nil;
-#ifdef __APPLE__
-            if ( [window unfoldedHeight] > 20.0 )   // folded window -> save unfolded size
-                sString = propertyListFromFloat([window unfoldedHeight]);
-#endif
-            if (sString)
-                [snapArray addObject:[NSArray arrayWithObjects:[doc filename], rString, sString, nil]];
-            else
-                [snapArray addObject:[NSArray arrayWithObjects:[doc filename], rString, nil]];
-        }
-    }
-
-    {   NSString    *path = vhfPathWithPathComponents(vhfUserLibrary(APPNAME), @".snapshots", nil);
-        NSString    *file, *name = @"Default.plist";
-        NSSavePanel *savePanel = [NSSavePanel savePanel];
-
-        if ( ! [[NSFileManager defaultManager] fileExistsAtPath:path])
-            [[NSFileManager defaultManager] createDirectoryAtPath:path attributes:nil];
-        file = vhfPathWithPathComponents(path, name, nil);
-
-        [savePanel setRequiredFileType:@"plist"];
-        //[savePanel setCanCreateDirectories:NO];
-        if ( [savePanel runModalForDirectory:path file:name] )
-            file = [savePanel filename];
-        else
-            return;
-        if ( [file rangeOfString:name].length )
-            [defaults setObject:snapArray forKey:@"snapShotDocuments"];
-
-        [snapArray writeToFile:file atomically:YES];
-    }
-}
-- (void)restoreSnapshot:sender
-{   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
-    NSArray         *snapArray = [defaults objectForKey:@"snapShotDocuments"];
-    int             i;
-
-    if ( [sender isKindOfClass:[NSMenuItem class]] )
-    {   NSString    *path = vhfPathWithPathComponents(vhfUserLibrary(APPNAME), @".snapshots", nil);
-        NSString    *file, *name = @"Default.plist";
-        NSOpenPanel *openPanel = [NSOpenPanel openPanel];
-
-        file = vhfPathWithPathComponents(path, name, nil);
-        [openPanel setRequiredFileType:@"plist"];
-        if ( [openPanel runModalForDirectory:path file:name] )
-            file = [openPanel filename];
-        else
-            return;
-        if ( ! (snapArray = [NSArray arrayWithContentsOfFile:file]) )
-            snapArray = [defaults objectForKey:@"snapShotDocuments"];
-    }
-
-    for (i=0; i<[snapArray count]; i++)
-    {   NSArray *array = [snapArray objectAtIndex:i];
-
-        if ( [array isKindOfClass:[NSString class]] )
-            [self openFile:[snapArray objectAtIndex:i]];
-        else if ([array count] >= 1)
-        {   [self openFile:[array objectAtIndex:0]];
-            if (document && [array count] >= 2) // point or rect
-            {    NSArray    *components = [[array objectAtIndex:1] componentsSeparatedByString:@" "];
-
-                if ( [components count] >= 4 )       // rectangle
-                {   NSRect  rect = rectFromPropertyList([array objectAtIndex:1]);
-
-                    [[document window] setFrame:rect display:NO];
-#ifdef __APPLE__
-                    if ( [array count] >= 3 &&  // unfoldedSize
-                        [[array objectAtIndex:2] respondsToSelector:@selector(floatValue)] )
-                    {   float   h = [[array objectAtIndex:2] floatValue];
-                        [[document window] setUnfoldedHeight:h];
-                    }
-#endif
-                }
-                else                            // point only (v 3.9.1 only)
-                {   NSPoint p = pointFromPropertyList([array objectAtIndex:1]);
-
-                    [[document window] setFrameOrigin:p];
-                }
-            }
-        }
-    }
-}
-
 /*
  * Methods to load model files for the various panels.
  */
@@ -997,27 +822,10 @@ typedef enum
     {
         if (![NSBundle loadModelNamed:@"Info" owner:self])
             NSLog(@"Cannot load Info interface file");
-#ifdef GNUSTEP_BASE_VERSION // FIXME: NSApplication on GNUstep has an icar named "_infoPanel" (2009-06-24)
-        if ( !infoPanel && [self valueForKey:@"_infoPanel"] )
-            infoPanel = [self valueForKey:@"_infoPanel"];
-#endif
     }
 
     [serialNumber setStringValue:@""];
 
-    /* set version number and date of compilation */
-    {   NSDictionary    *infoDict = [[NSBundle mainBundle] infoDictionary];
-        NSString        *version = [infoDict objectForKey:@"CFBundleVersion"];
-
-        if ( version )
-        {   NSString    *compileDate = [self compileDate];
-
-            if ( compileDate )
-                version = [version stringByAppendingFormat:@" (%@)", compileDate];
-            [infoVersionNo setStringValue:version]; // ex: 3.9.1 pre 1 (2010-02-13)
-        }
-    }
-
     [[NSNotificationCenter defaultCenter] postNotificationName:InfoPanelWillDisplay
                                                         object:nil userInfo:nil];
 
@@ -1030,50 +838,8 @@ typedef enum
     [self displayInfo];
     [infoPanel makeKeyAndOrderFront:sender];
 }
-- (NSString*)version
-{   NSDictionary    *infoDict = [[NSBundle mainBundle] infoDictionary];
-    NSString        *version;
-
-    version = [infoDict objectForKey:@"CFBundleVersion"];   // Apple
-    if ( ! version )
-        version = [infoDict objectForKey:@"NSVersion"];     // GNUstep
-    if ( ! version )
-        version = infoVersionNo;
-    return version;
-}
-- (NSString*)compileDate
-{   char    *compileDate = __DATE__;    // Apr 10 2010
-    char    date[15];
-
-    if ( strlen(compileDate) == 11 )    // Apr  2 2010 -> 2010-04-02
-    {   NSArray *mArray;
-        char    mStr[4];
-        int     m;
-
-        strncpy(mStr, compileDate, 3); mStr[3] = 0;
-        mArray = [NSArray arrayWithObjects:@"Jan", @"Feb", @"Mar", @"Apr", @"May", @"Jun", @"Jul", @"Aug", @"Sep", @"Oct", @"Nov", @"Dec", nil];
-        if ( (m = [mArray indexOfObject:[NSString stringWithUTF8String:mStr]]) != NSNotFound )
-        {   m ++;
-            strncpy(date, compileDate+7, 4);                            // YYYY
-            date[4] = '-';
-            date[5] = (m >= 10) ? '1' : '0';                            // MM
-            if (m >= 10) m -= 10;
-            date[6] = '0' + m;
-            date[7] = '-';
-            date[8] = (compileDate[4] == ' ') ? '0' : compileDate[4];   // DD
-            date[9] = compileDate[5];
-            date[10] = 0;
-            compileDate = date;
-        }
-    }
-    if ( compileDate )
-        return [NSString stringWithCString:compileDate encoding:NSASCIIStringEncoding];
-    else
-        return nil;
-}
-- (id)infoVersionNo     { return infoVersionNo; }   // ex: 3.9.0
-- (id)infoVersionText	{ return kindOfVersion; }   // ex: "Licensed version"
-- (id)infoSerialText	{ return serialNumber; }    // ex: 020001
+- (id)infoVersionText	{ return kindOfVersion; }
+- (id)infoSerialText	{ return serialNumber; }
 
 - (void)showPrefsPanel:sender
 {
@@ -1092,82 +858,38 @@ typedef enum
     return preferencesPanel;
 }
 
-- (void)checkForUpdate:sender
-{
-#ifdef __APPLE__
-    [[UpdateController sharedInstance] checkForUpdates:sender];
-#else   // GNUstep: TODO
-    {   NSString    *site;
-
-        site = NSLocalizedString(@"http://www.cenon.info/news/news_gb.html", News);
-        //site = NSLocalizedString(@"http://www.cenon.info/dApple_gb.html", Download);
-        [[NSWorkspace sharedWorkspace] openURL:[NSURL URLWithString:site]];
-    }
-#endif
-}
-
-/* Show Web Page
- * created: 2010-05-19
- */
-- (void)showWebPage:(id)sender
-{   NSString    *site;
-    int         tag = [sender tag];
-
-	if ([sender isKindOfClass:[NSMatrix class]])
-		tag = [sender selectedTag];
-	switch (tag)
-    {
-        default: site = NSLocalizedString(@"http://www.cenon.info", Web Site); break;
-        case 1:  site = NSLocalizedString(@"http://www.cenon.info/support_faq_gb.html", Web FAQ); break;
-        case 2:  site = NSLocalizedString(@"http://www.cenon.info/releaseNotes_gb.html", Web Releae Notes); break;
-        case 3:  site = NSLocalizedString(@"mailto:service@vhf.de?subject=Cenon%20Feedback", eMail Address); break;
-        case 4:  site = NSLocalizedString(@"http://www.cenon.info/news/news_gb.html", News); break;
-                 //site = NSLocalizedString(@"http://www.cenon.info/dApple_gb.html", Download); break;
-    }
-	[[NSWorkspace sharedWorkspace] openURL:[NSURL URLWithString:site]];
-}
-
 /* load PDF documentation
  * Note: each module can add a help menu entry to load it's docu
- * modified: 2007-07-22
+ * modified: 2007-07-19
  */
 #if defined(GNUSTEP_BASE_VERSION) || defined(__APPLE__)	// GNUstep or Apple
 - (void)showHelp:sender
 {   NSArray     *localizations;
     NSString    *locale, *path, *helpFile;
-    int         l, i;
+    int         i;
 
     localizations = [NSBundle preferredLocalizationsFromArray:[[NSBundle mainBundle] localizations]];
+    locale = [[localizations objectAtIndex:0] stringByAppendingString:@".lproj"];
 
-    for (l=0; l<[localizations count]; l++ )
+    /* load additional modules */
+    for (i=0; i<3; i++)
     {
-        locale = [[localizations objectAtIndex:l] stringByAppendingString:@".lproj"];
-        for (i=0; i<3; i++)
+        switch (i)
         {
-            switch (i)
-            {
-                case 0: path = [[NSBundle mainBundle] resourcePath];
-                    helpFile = vhfPathWithPathComponents(path, locale, @"Cenon.pdf", nil);
-                    break;
-                case 1: path = vhfUserLibrary(APPNAME);
-                    helpFile = vhfPathWithPathComponents(path, @"Docu", locale, @"Cenon.pdf", nil);
-                    break;
-                case 2: path = vhfLocalLibrary(APPNAME);
-                    helpFile = vhfPathWithPathComponents(path, @"Docu", locale, @"Cenon.pdf", nil);
-                    break;
-                default:
-                    return;
-            }
-            if ( [[NSFileManager defaultManager] fileExistsAtPath:helpFile] )
-            {   [[NSWorkspace sharedWorkspace] openFile:helpFile];
-                l = [localizations count];
-                break;
-            }
+            case 0: path = [[NSBundle mainBundle] resourcePath]; break;
+            case 1: path = vhfUserLibrary(APPNAME);              break;
+            case 2: path = vhfLocalLibrary(APPNAME);             break;
+            default: break;
         }
+        helpFile = vhfPathWithPathComponents(path, @"Docu", locale, @"Cenon.pdf", nil);
+        [[NSWorkspace sharedWorkspace] openFile:helpFile];
     }
 
-    /*if ( !helpPanel && ![[NSBundle mainBundle] loadModelNamed:@"Help" owner:self] )
-            NSLog(@"Cannot load Help interface file");
+    /*if (!helpPanel)
+    {
+        if (![[NSBundle mainBundle] loadModelNamed:@"Help" owner:self])
+            NSLog(@"Cannot load Help interface file");	
+    }
     [helpPanel setFrameAutosaveName:@"HelpPanel"];
     [helpPanel makeKeyAndOrderFront:sender];*/
 }
@@ -1186,7 +908,7 @@ typedef enum
     [inspectorPanel setBecomesKeyOnlyIfNeeded:YES];
     [inspectorPanel orderFront:sender];
 }
-- inspectorPanel
+- inspectorPanel;
 {
     return inspectorPanel;
 }
@@ -1202,7 +924,7 @@ typedef enum
     [transformPanel setFrameAutosaveName:@"TransformPanel"];
     [transformPanel makeKeyAndOrderFront:sender];
 }
-- transformPanel
+- transformPanel;
 {
     return transformPanel;
 }
@@ -1213,11 +935,12 @@ typedef enum
     {
         if (![NSBundle loadModelNamed:@"ProjectSettingsPanel" owner:self])
             NSLog(@"Cannot load ProjectSettingsPanel interface file");	
+        [projectSettingsPanel init];
     }
     //[projectSettingsPanel setFrameAutosaveName:@"ProjectSettingsPanel"];
     [projectSettingsPanel makeKeyAndOrderFront:sender];
 }
-- projectSettingsPanel
+- projectSettingsPanel;
 {
     return projectSettingsPanel;
 }
@@ -1315,19 +1038,19 @@ typedef enum
  * modified: 2004-12-03
  */
 - (void)setCurrent2DTool:sender
-{   id          cursor;
-    id          matrix = [[[toolPanel contentView] subviews] objectAtIndex:0];
-    static id   rotateCursor = nil, crossCursor = nil, scissorCursor = nil;	// the cursors
+{   id		cursor;
+    id		matrix = [[[toolPanel contentView] subviews] objectAtIndex:0];
+    static id	rotateCursor = nil, crossCursor = nil, scissorCursor = nil;	// the cursors
 
     if ( [self currentDocument] )
     {
-        if (!sender && current2DTool)   // temporary arrow mode by pressing Alternate
+        if (!sender && current2DTool)
         {   current2DTool = 0;
             [[[self currentDocument] scrollView] setDocumentCursor:[NSCursor arrowCursor]];
             return;
         }
 
-        if (sender && sender != self)	// command key pressed
+        if (sender && sender!=self)	// command key pressed
             [[[self currentDocument] window] endEditingFor:nil];	// end editing of text
         current2DTool = [[matrix selectedCell] tag];
         switch (current2DTool)
@@ -1431,35 +1154,13 @@ typedef enum
 - (BOOL)control		{ return control; }
 - (BOOL)alternate	{ return alternate; }
 
-/* created:  1995-11-05
- * modified: 2010-02-18 (right mouse down exits editing modes)
- *           2009-03-27
+/*
+ * modified: 05.11.95
  *
  * We override this because we need to find out when the command key is down
- * and to change ',' to '.' for the decimal separator on the numeric pad
  */
 - (void)sendEvent:(NSEvent *)event
 {
-#ifdef __APPLE__
-    /* Change ',' to '.' */
-    if ( event && [event type] == NSKeyDown && [event keyCode] == 65 )    // decimal-key: we want a '.'
-    {   NSString    *chars = [event charactersIgnoringModifiers];
-
-        chars = @".";   // we change ',' to '.'
-        event = [NSEvent keyEventWithType:[event type]
-                                 location:[event locationInWindow]
-                            modifierFlags:[event modifierFlags]
-                                timestamp:[event timestamp]
-                             windowNumber:[event windowNumber]
-                                  context:[event context]
-                               characters:chars
-              charactersIgnoringModifiers:chars
-                                isARepeat:[event isARepeat]
-                                  keyCode:[event keyCode]];
-    }
-#endif
-
-    /* find out if command is pressed */
     if (event && [event type] < NSAppKitDefined)
     {	BOOL	lastCommand = command;
 
@@ -1471,13 +1172,13 @@ typedef enum
         /* temporary set arrow mode
          */
         if (command != lastCommand)
-            [self setCurrent2DTool:(command) ? nil : (id)self];
+            [self setCurrent2DTool:(command) ? nil : self];
 
         if (command && [event type] == NSKeyDown &&
             [[self mainWindow] isMemberOfClass:[DocWindow class]])
-        {   NSString    *string = [event charactersIgnoringModifiers];
-            int         i = [string intValue];
-            id          fe = [[self mainWindow] fieldEditor:NO forObject:nil];
+        {   NSString	*string = [event charactersIgnoringModifiers];
+            int		i = [string intValue];
+            id		fe = [[self mainWindow] fieldEditor:NO forObject:nil];
 
             /* set inspector panel only, if no text ruler is activated,
              * to avoid setting the inspector when rulers are copied
@@ -1489,19 +1190,10 @@ typedef enum
                     if (!inspectorPanel)
                         [self showInspectorPanel:self];
                     [inspectorPanel setLevelAt:i-1];
-                    return;
                 }
             }
         }
-        /* right mouse down - we exit editing mode */
-        if ([event type] == NSRightMouseDown && current2DTool)
-        {   id  matrix = [[[toolPanel contentView] subviews] objectAtIndex:0];
-
-            [matrix selectCellWithTag:0];
-            [self setCurrent2DTool:self];
-        }
     }
-
     [super sendEvent:event];
 }
 
