@@ -1,17 +1,11 @@
 /* DXFImport.m
  * DXF import object
  *
- * Copyright (C) 1996-2012 by vhf interservice GmbH
+ * Copyright (C) 1996-2007 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-05-01
- * modified: 2012-02-04 (-scanGroup: transform coordinates from OCS to WCS, if necessary)
- *           2011-02-27 (-init: initialize group.handle, state.color, blockScanner, rable, vivibleList)
- *           2010-10-31 (buildArc(): dx, dy calced with double)
- *           2010-09-11 (-importDXF: try UTF8 and Latin encodings to make GNUstep happy)
- *           2010-06-11 (buildArc(): 360.0 - acos(cn), was 180.0 - )
- *           2010-04-03 (-getArc: negative 360 deg arcs work now, buildArc(): dx == 0 case)
- *           2007-01-30 (close PolyLine: check for start == end point)
+ * modified: 2007-01-30 (close PolyLine: check for start == end point)
  *
  * This file is part of the vhf Import Library.
  *
@@ -64,7 +58,7 @@ static BOOL gotoTable(NSScanner *scanner, NSString *name);
 static BOOL gotoGroup( NSScanner *scanner, NSString *name);
 static NSArray *getTableFromData(NSString *data);
 static NSColor *getColorFromTable(NSString *str, NSArray *table);
-static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *angle);
+static void buildArc(NSPoint beg, NSPoint end, float a, NSPoint *ctr, float *angle);
 
 @interface DXFImport(PrivateMethods)
 - (BOOL)getHeader:(NSString*)data;
@@ -80,7 +74,7 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
 - (BOOL)getCircle:(NSScanner*)scanner :(NSPoint*)ctr :(NSPoint*)start :(float*)angle;
 - (BOOL)getArc:(NSScanner*)scanner :(NSPoint*)ctr :(NSPoint*)start :(float*)angle;
 - (BOOL)getText :(NSScanner*)scanner mtext:(BOOL)mext :(NSString**)string :(float*)angle :(NSPoint*)origin :(float*)size :(float*)ar :(int*)alignment;
-- (BOOL)getInsert:(NSScanner*)scanner :(id)cList;
+- (BOOL)getInsert:(NSScanner*)scanner :cList;
 - (void)updateBounds:(NSPoint)p;
 
 - (void)addText:(NSString*)text :(NSString*)font :(float)angle :(float)size :(float)ar at:(NSPoint)p 	toLayer:(NSString*)layerName;	// old
@@ -418,13 +412,6 @@ static NSColor *getColorFromTable(NSString *str, NSArray *table)
     group.text = nil;
     group.name = nil;
     group.layer = nil;
-    group.handle = nil;
-
-    state.color = nil;
-
-    blockScanner = nil;
-    table = nil;
-    visibleList = nil;
 
     return self;
 }
@@ -435,17 +422,12 @@ static NSColor *getColorFromTable(NSString *str, NSArray *table)
 }
 
 /* created:   1996-01-25
- * modified:  2010-09-11 (load UTF8 instead of ASCII, if it fails try Latin)
+ * modified:  2002-10-26
  * parameter: dxfData	the DXF data stream
  * purpose:   start interpretation of dxfData
  */
 - (id)importDXF:(NSData*)dxfData
-{   NSString	*data = [[[NSString alloc] initWithData:dxfData
-                                            encoding:NSUTF8StringEncoding] autorelease];
-
-    if ( ! data )   // try latin
-        data = [[[NSString alloc] initWithData:dxfData
-                                      encoding:NSISOLatin1StringEncoding] autorelease];
+{   NSString	*data = [[[NSString alloc] initWithData:dxfData encoding:NSASCIIStringEncoding] autorelease];
 
     newLineSet = [NSCharacterSet characterSetWithCharactersInString:@"\r\n"];
     skipSet = [NSCharacterSet characterSetWithCharactersInString:@" \t"];
@@ -572,8 +554,8 @@ static NSColor *getColorFromTable(NSString *str, NSArray *table)
  * modified: 2005-09-26 (close polyline with arc)
  */
 - (BOOL)getGraphicFromData:(NSScanner*)scanner :(id)cList
-{   NSPoint     p0, p1;
-    NSString    *name;
+{   NSPoint	p0, p1;
+    NSString	*name;
 
     /* goto name line */
     [scanner scanUpToCharactersFromSet:newLineSet intoString:NULL];
@@ -586,7 +568,7 @@ static NSColor *getColorFromTable(NSString *str, NSArray *table)
 
     switch ( state.mode )
     {
-        case MODE_NORMAL:
+	case MODE_NORMAL:
             /* line */
             if ( [name isEqual:GRPLINE] )
             {
@@ -1027,46 +1009,30 @@ static NSColor *getColorFromTable(NSString *str, NSArray *table)
     return YES;
 }
 
-/* Note: see page 323 of DXF book
- * modified: 2010-10-31 (dx, dy calced with double)
- *           2010-06-11 (360 - acos(cn))
- *           2010-04-03
- */
-static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *angle)
-{   NSPoint	p;
-    double	l, ang, dx, dy, r, an, h;
-    double  mx, my, begx = beg.x, begy = beg.y, endx = end.x, endy = end.y;
+static void buildArc(NSPoint beg, NSPoint end, float a, NSPoint *ctr, float *angle)
+{   NSPoint	p, m;
+    double	l, ang, dy, r, an, h, sn;
 
     ang = 4.0 * RadToDeg(atan( a ));
-    l = sqrt(SqrDistPoints(beg, end));  // length of arc from point to point
-    h = (a*l)/2.0;                      // height of arc
-    mx = (begx+endx)/2.0; my = (begy+endy)/2.0; // mit point between start and end
-    dx = mx - begx;                     // 
-    dy = my - begy;                     // 
-    //if (h>0)	/* don't know if this is correct */
+    l = sqrt(SqrDistPoints(beg, end));
+    h = (a*l)/2.0;
+    m.x = (beg.x+end.x)/2.0; m.y = (beg.y+end.y)/2.0;
+    dy = m.y - beg.y;
+    //if (h>0)	/* dont know if this is correct */
     //    ang = -ang;
 //printf("h:%f ang:%f\n", h, ang);
     /* asin(dy/(l/2)) = angle from 0 degree to l, we may use atan(2h/l) instead */
-    if ( Abs(dx) < TOLERANCE )              // larger y component (vertical arc) (only tested for vertical case !)
-    {   double  cn = Max( -1.0, Min( 1.0, dx / (l/2.0) ) );
-        if ( beg.y > end.y )
-            an = 360.0 - (RadToDeg(acos(cn)) - (((ang<0) ? -90.0 : 90.0)-ang/2.0));
-        else
-            an = RadToDeg(acos(cn)) + (((ang<0) ? -90.0 : 90.0)-ang/2.0);
-    }
-    else                                    // larger x component
-    {   double  sn = Max( -1.0, Min( 1.0, dy / (l/2.0) ) );
-        if ( beg.x > end.x )
-            an = 180.0 - (RadToDeg(asin(sn)) - (((ang<0) ? -90.0 : 90.0)-ang/2.0));
-        else
-            an = RadToDeg(asin(sn)) + (((ang<0) ? -90.0 : 90.0)-ang/2.0);
-    }
+    sn = Max( -1.0, Min( 1.0, dy / (l/2.0) ) );
+    if ( beg.x>end.x )
+        an = 180.0 - (RadToDeg(asin(sn)) - (((ang<0) ? -90.0 : 90.0)-ang/2.0));
+    else
+        an = RadToDeg(asin(sn)) + (((ang<0) ? -90.0 : 90.0)-ang/2.0);
     r = Abs(l/(2.0*sin(DegToRad(ang/2.0))));
 //NSLog(@"0 h=%f an=%f dy=%f l=%f ang=%f r=%f", h, an, dy, l, ang, r);
     p.x = beg.x + r; p.y = beg.y;
     vhfRotatePointAroundCenter(&p, beg, an);
     *ctr = p;
-    *angle = (float)ang;
+    *angle = ang;
 }
 
 /* created:   18.05.93
@@ -1153,7 +1119,7 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
 }
 
 /* created:   1993-05-17
- * modified:  2010-04-03 (negative 360 deg arcs work now)
+ * modified:  2004-08-04
  *
  * purpose:   get arc
  * parameter: cp (the dxf data)
@@ -1172,22 +1138,17 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
     state.color = [self currentColor];
     ctr->x = DeviceResToInternal(group.x0, res) + state.offset.x;
     ctr->y = DeviceResToInternal(group.y0, res) + state.offset.y;
-    //FIXME: group.extX, group.extY, group.extZ
     r = DeviceResToInternal(group.width, res);
     ba = group.begAngle;
     ea = group.endAngle;
 
     start->x = ctr->x + r;
     start->y = ctr->y;
-    *angle = 0.0;
-    if ( Abs(ea - ba) >= 360.0 )
-        *angle = ea - ba;
-    if (ba >= 360.0) ba -= 360.0;
-    if (ea < ba)     ea += 360.0;
+    if (ba>=360.0) ba-=360.0;
+    if (ea<ba) ea+=360.0;
     vhfRotatePointAroundCenter(start, *ctr, ba);
 
-    if ( *angle == 0.0 )
-        *angle = ea - ba;
+    *angle = ea - ba;
 
     state.width = 0.0;
 
@@ -1292,13 +1253,13 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
  * parameter: scanner (the dxf data)
  *            cList
  */
-- (BOOL)getInsert:(NSScanner*)scanner :(id)cList
-{   NSPoint             point;				/* position of the text */
-    NSString            *name, *string;
-    float               angle;
-    NSScanner           *myBlockScanner = nil;
-    int                 location;
-    NSAutoreleasePool   *pool = [[NSAutoreleasePool alloc] init];
+- (BOOL)getInsert:(NSScanner*)scanner :cList
+{   NSPoint		point;				/* position of the text */
+    NSString		*name, *string;
+    float		angle;
+    NSScanner		*myBlockScanner = nil;
+    int			location;
+    NSAutoreleasePool	*pool = [[NSAutoreleasePool alloc] init];
 
     [self scanGroup:scanner];
     if ( [visibleList count] && ![visibleList containsObject:group.handle])
@@ -1405,62 +1366,13 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
     return color;
 }
 
-/* arbitrary axis algorithm - transform OCS (Object) to WCS (World)
- * build the cross product
- *
- * W        our coordinate             [WCS]
- * AZ (N)   the extrusion direction    [WCS]
- * return   the transformed coordinate [OCS]
- * created: 2012-02-03
- */
-static V3Point crossProduct(const V3Point a, const V3Point b)
-{   V3Point result;
-
-    result.x = a.y * b.z - a.z * b.y;
-    result.y = a.z * b.x - a.x * b.z;
-    result.z = a.x * b.y - a.y * b.x;
-    return result;
-}
-static V3Point scaleToUnit(V3Point p)
-{   double  len = sqrt(p.x*p.x + p.y*p.y + p.z*p.z);
-    
-    if (len != 0)
-    {   p.x /= len;
-        p.y /= len;
-        p.z /= len;
-    }
-    return p;
-}
-static V3Point transformOCS(V3Point pOCS, V3Point AZ)
-{   V3Point AX, AY, p;
-
-    if ( Abs(AZ.x) < 1.0/64.0 && Abs(AZ.y) < 1.0/64.0 )
-        AX = crossProduct(V3MakePoint(0.0, 1.0, 0.0), AZ);   // transform using unit vector Y
-    else
-        AX = crossProduct(V3MakePoint(0.0, 0.0, 1.0), AZ);   // transform using unit vector Z
-    AX = scaleToUnit( AX );  // scale vector to unit (length = 1.0)
-    AY = crossProduct(AZ, AX);
-    AY = scaleToUnit( AY );
-
-    /* these are direction cosines, we have to rotate each axis around this */
-    {   double x = pOCS.x, y = pOCS.y, z = pOCS.z;
-
-        p.x = x * AX.x + y * AY.x + z * AZ.x;
-        p.y = x * AX.y + y * AY.y + z * AZ.y;
-        p.z = x * AX.z + y * AY.z + z * AZ.z;
-    }
-    return p;
-}
-
 /* get group entries
  * scanner starts at id line of first entry
  * scanner scans until it reaches the next group
- * created:  1997-03-19
- * modified: 2009-02-06 (read in extrusion direction)
+ * created:  19.03.97
  */
 - (BOOL)scanGroup:(NSScanner*)scanner
-{   BOOL    exitLoop = NO;
-
+{
     [group.text release]; group.text = nil;
     [group.name release]; group.name = nil;
     [group.layer release]; group.layer = nil;
@@ -1475,7 +1387,6 @@ static V3Point transformOCS(V3Point pOCS, V3Point AZ)
     group.x3 = group.y3 = 0.0;
     group.a = 0.0;
     group.flags = group.genFlags = 0;
-    group.extX = group.extY = 0.0; group.extZ = 1.0;
 
     while ( ![scanner isAtEnd] )
     {	int	i, location = [scanner scanLocation];
@@ -1597,46 +1508,14 @@ static V3Point transformOCS(V3Point pOCS, V3Point AZ)
                 if (![scanner scanInt:&group.numGrp])
                     group.numGrp = 0;
                 break;
-            case ID_EXT_X:
-                if (![scanner scanFloat:&group.extX])
-                    group.extX = 0.0;
-                break;
-            case ID_EXT_Y:
-                if (![scanner scanFloat:&group.extY])
-                    group.extY = 0.0;
-                if ( group.extX != 0.0 || group.extY != 0.0 )   // FIXME: extrusion direction
-                    NSLog(@"DXF-Import: extrusion direction not supported. File-Location = %d", [scanner scanLocation]);
-                break;
-            case ID_EXT_Z:
-                if (![scanner scanFloat:&group.extZ])
-                    group.extZ = 1.0;
-                break;
-            case ID_GROUP:
+           case ID_GROUP:
                 [scanner setScanLocation:location];
-                exitLoop = YES;
-                break;
+                return YES;
             default:
                 break;
         }
-        if ( exitLoop )
-            break;
         gotoNextLine(scanner);	// goto id line
     }
-
-    /* transform coordinates from OCS to WCS (only if extrusion direction tells us so) */
-    if ( group.extX != 0.0 || group.extY != 0.0 || group.extZ != 1.0 )
-    {   V3Point N = V3MakePoint(group.extX, group.extY, group.extZ), p;
-
-        p = transformOCS(V3MakePoint(group.x0, group.y0, 0.0), N);
-        group.x0 = p.x; group.y0 = p.y;
-        p = transformOCS(V3MakePoint(group.x1, group.y1, 0.0), N);
-        group.x1 = p.x; group.y1 = p.y;
-        p = transformOCS(V3MakePoint(group.x2, group.y2, 0.0), N);
-        group.x2 = p.x; group.y2 = p.y;
-        p = transformOCS(V3MakePoint(group.x3, group.y3, 0.0), N);
-        group.x3 = p.x; group.y3 = p.y;
-    }
-
     return YES;
 }
 
