@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1995-09-06
- * modified: 2005-03-28 (+ VHFRange)
+ * modified: 2005-11-06
  *
  * This file is part of the vhf Shared Library.
  *
@@ -140,7 +140,8 @@ static __inline__ VHFLine VHFMakeLine(float x0, float y0, float x1, float y1)
 
 #define MMToInternal(v)		((v)*72.0/25.4)	/* convert mm to internal unit */
 #define InternalToMM(v)		((v)*25.4/72.0)	/* convert internal unit to mm */
-#define RectInternalToMM(r)	NSMakeRect(InternalToMM((r).origin.x), InternalToMM((r).origin.y), InternalToMM((r).size.width), InternalToMM((r).size.height))
+#define RectInternalToMM(r)	NSMakeRect( InternalToMM((r).origin.x),   InternalToMM((r).origin.y), \
+                                            InternalToMM((r).size.width), InternalToMM((r).size.height) )
 #define InchToMM(v)		((v)/25.4)	/* convert inch to mm */
 #define	PT			1.0
 #define INCH			72.0
